#!/usr/bin/perl
use Fcntl;
use AnyDBM_File;
use Socket;
use Getopt::Std;

($path,$program) = $0 =~ /^(.*)\/(.*)$/;

if(!getopts('g:i:hv')) {
    print STDERR <<EOF;
Usage: $program [-i interval][-g group][-h|-v]
    -i : group job interval (second)
    -g : job group number
    -h : show this message
    -v : show version

EOF
    exit;
}
if ( $opt_h ) {
    print STDERR <<EOF;
Usage: $program [-i interval][-g group][-h|-v]
    -i : group job interval (second)
    -g : job group number
    -h : show this message
    -v : show version

EOF
    exit;
}
if ( $opt_v ) {
    print <<EOF;
$program : version 2.0 build 6

EOF
    exit;
}

$interval = $opt_i;
$param = $opt_g;

$manager_dir = "/var/www/manager/data";
$data_file = "$manager_dir/scan_list.csv";
$check_db_file = "$manager_dir/scan_check_list";
$scan_command = "/var/www/manager/bin/scan_launcher2.sh";
$check_file = "$manager_dir/scan_check_file";
$check_status = "$manager_dir/scan_begin_file";
$interval = 1800 unless $interval;
$flag = 0;

if ( -f $check_db_file ) {
    unlink($check_db_file);
}

foreach $n (1..4) {
    if ( -f "${check_file}_$n" ) {
        unlink("${check_file}_$n");
    }
}

if ( -f $check_status ) {
    print "The scan is being processed.\n";
    exit(1);
}

open(DATA,">$check_status");
print DATA localtime, "\n";
close(DATA);

print "---------------------\n";
print "Scan prepare:\n";
$max = 0;
tie( %check_data, 'AnyDBM_File', $check_db_file, O_CREAT|O_RDWR, 0644 );
open(LIST,$data_file);
while(<LIST>) {
    chomp;
    ($host,$num) = split(/,/,$_);
    ($hostname,$alias,$atype,$len,@addrs) = gethostbyname($host);
    $ip = sprintf("%d.%d.%d.%d",unpack("CCCC",$addrs[0]));
    print "$ip -> $num\n";
    if ( $check_data{$ip} eq "" ) {
        $check_data{$ip} = 0;
    }
    if ( $param eq $num ) {
        if($check_data{$ip} == 0) {
            push(@{$list[0]},$ip);
            #print "pushed\n";
        }
    } elsif ( $param eq "" ) {
        if($check_data{$ip} == 0) {
            push(@{$list[$num]},$ip);
            #print "pushed\n";
        }
        $max = $num if $max < $num;
    }
}
close(LIST);

print "---------------------\n";
print "Scan JOB:\n";
if ( $param ne "" ) {
    #print join(",",@{$list[0]}),"\n";
    $num = 0;
    foreach $ip (@{$list[0]}) {
        $check_data{$ip} = 2;
        system("$scan_command 0 $ip");
        #print("Lancher:$scan_command $ip\n");
        print("$ip\n");
        $num++;
    }
    $rem = &result_check($num,$interval,"${check_file}_0") if $num;
    push(@rem_list,"${check_file}_0") if $rem;
} else {
    foreach $n ( 1..$max ) {
        print "No.$n\n";
        #print join(",",@{$list[$n]}),"\n";
        $num = 0;
        foreach $ip (@{$list[$n]}) {
            $check_data{$ip} = 2;
            system("$scan_command $n $ip");
            #print("Lancher:$scan_command $ip\n");
            print("$ip\n");
            $num++;
        }
        $rem = &result_check($num,$interval,"${check_file}_$n") if $num;
        push(@rem_list,"${check_file}_$n") if $rem;
    }
}

# Ǹγǧ
@IPS = ();
foreach $ip (sort keys %check_data) {
    next if $check_data{$ip} != 2;
    print "$ip not complete. check wait.\n";
    push(@IPS,$ip);
}

# ̤
if(@IPS) {
    $interval = 1080;
    while($interval && @IPS) {
        
        # check result file
        foreach $file (@rem_list) {
          if ( -f $file ) {
            open(FILE,$file);
            @list = <FILE>;
            close(FILE);
            @H = @IPS;
            @IPS = ();
            foreach $ip (@H) {
                $flag = 0;
                foreach $d (@list) {
                    chomp($d);
                    ($host,$stat) = split(/:/,$d);
                    if ( $ip eq $host ) {
                        if ( $stat eq "OK" ) {
                            $check_data{$ip} = 5;
                        } elsif ( $stat eq "10" || $stat eq "137" ) {
                            $check_data{$ip} = 3;
                        } elsif ( $stat eq "255" ) {
                            $check_data{$ip} = 4;
                        } else {
                            $check_data{$ip} = 0;
                        }
                        $flag = 1;
                        last;
                    }
                }
                push(@IPS,$ip) unless $flag;
            }
          }
        }
        sleep(5);
        $interval--;
    }
}

# result
$total = 0;
$ok = 0;
$faile = 0;
$warn = 0;
$critical = 0;
foreach $ip (sort keys %check_data) {
    $res = $check_data{$ip};
    $total++;
    if($res eq "") {
        print "$ip : not scan\n";
        $faile++;
    } else {
        if($res == 1) {
            print "$ip : scan ok\n";
            $ok++;
        } elsif($res == 4 || $res == 5) {
            print "$ip : scan limit over\n";
            $warn++;
        } elsif($res == 3) {
            print "$ip : scan failed\n";
            $faile++;
        } elsif($res == 2) {
            print "$ip : scan timeout\n";
            $faile++;
        } else {
            print "$ip : scan alert\n";
            $critical++;
        }
    }
}
print <<EOF;
---------------------
scan summary:
     Success  : $ok
     Warning  : $warn
     Critical : $critical
     Failed   : $faile
     ----------------
     Total    : $total

EOF
untie(%check_data);

unlink($check_status);
#unlink($check_file);
#unlink($check_db_file);

if ( $ok != $total ) {
    system(qq(logger "all_scan failed. (OK=$ok,WARN=$warn,NG=$faile)"));
    exit 1;
}
exit 0;

sub result_check {
    my ($num,$interval,$chkfile) = @_;
    my(@list);
    
    print "check $num client(s)\n";
    
    $timer = int($interval/5);
    $|=1;
    while($timer) {
        sleep(5);print ".";
        $timer--;
        next unless -f $chkfile;
        open(FILE,$chkfile);
        @list = <FILE>;
        close(FILE);
        
        foreach $d (@list) {
            chomp($d);
            ($ip,$stat) = split(/:/,$d);
            if ( $check_data{$ip} == 2 ) {
                if ( $stat eq "OK" ) {
                    $check_data{$ip} = 1;
                } elsif ( $stat eq "10" || $stat eq "137" ) {
                    $check_data{$ip} = 3;
                } elsif ( $stat eq "255" ) {
                    $check_data{$ip} = 4;
                } else {
                    $check_data{$ip} = 0;
                }
                $num--;
            }
        }
        last if $num == 0;
    }
    print "\n";
    print "complete(remain=$num)\n";
    
    return $num;
}
 