#!/usr/bin/ksh
#
# httpd:       Apache httpd startup script
#
# Description: Apache httpd startup script
#
# February 08, 2012, Michael Perzl (michael@perzl.org)
#

NAME=httpd
PROG=${NAME}

PROG_BIN=/opt/freeware/sbin/apachectl

PIDFILE=`grep "^PidFile" /opt/freeware/etc/httpd/conf/psmt_httpd.conf|awk '{print $2}'`


# define some generic commands
AWK=/usr/bin/awk
CAT=/usr/bin/cat
ECHO=/usr/bin/echo
GREP=/usr/bin/grep
KILL=/usr/bin/kill
MKDIR=/usr/bin/mkdir
PRINTF=/usr/bin/printf
PS=/usr/bin/ps
RM=/usr/bin/rm
SLEEP=/usr/bin/sleep


# check for missing binaries (stale symlinks should not happen)
test -x ${PROG_BIN} ||
    {
      $ECHO "${PROG_BIN} not installed"
      if [ "$1" = "stop" ] ; then
          exit 0
      else
          exit 5
      fi
    }


# source config
if [ -f /etc/sysconfig/${NAME} ] ; then
    . /etc/sysconfig/${NAME}
fi


# Check for existence of needed config file and read it
HTTPD_CONFIG=/opt/freeware/etc/httpd/conf/psmt_httpd.conf
test -r ${HTTPD_CONFIG} ||
    {
      $ECHO "${HTTPD_CONFIG} not existing";
      if [ "$1" = "stop" ] ; then
          exit 0
      else
          exit 6
      fi
    }


case "$1" in
    start)
        if [ -r ${PIDFILE} ]; then
            pid=`$CAT ${PIDFILE}`
            if [ "`$PS -ef | $GREP -v grep | $GREP ${PROG} | $GREP ${pid} | $AWK '{ print $2 }' | $GREP ${pid}`" = "${pid}" ] ;
	    then
                $ECHO "Apache for PSMT httpd daemon is already running with PID ${pid}."
                exit 1
            else
                $RM -f ${PIDFILE}
            fi
        fi
        $PRINTF "Starting Apache httpd... "

        ## start daemon and write PID to file ${PIDFILE}
        if [ ! -d /var/run ];then
            $MKDIR -p /var/run
        fi
        ${PROG_BIN} start
        $ECHO "done."
        ;;
    stop)
        $PRINTF "Stopping Apache httpd daemon... "
        ## stop daemon
        if [ -r ${PIDFILE} ]; then
            ${PROG_BIN} stop
            $KILL -TERM `$CAT ${PIDFILE}`
            $RM -f ${PIDFILE}
        fi
        $ECHO "done."
        ;;
    status)
        if [ -r ${PIDFILE} ]; then
            pid=`$CAT ${PIDFILE}`
            if [ "`$PS -ef | $GREP -v grep | $GREP ${PROG} | $GREP ${pid} | $AWK '{ print $2 }' | $GREP ${pid}`" = "${pid}" ] ;
	    then
                $ECHO "Apache for PSMT httpd daemon is running with PID ${pid}."
            else
                $ECHO "Apache for PSMT httpd daemon is not running."
            fi
        else
            $ECHO "Apache for PSMT httpd daemon is not running."
        fi
        ;;
    condrestart)
        if [ -r ${PIDFILE} ]; then
            pid=`$CAT ${PIDFILE}`
            if [ "`$PS -ef | $GREP -v grep | $GREP ${PROG} | $GREP ${pid} | $AWK '{ print $2 }' | $GREP ${pid}`" = "${pid}" ] ;
	    then
                $0 stop
                $ECHO "Sleeping for 5 seconds for graceful httpd shutdown ..."
                $SLEEP 5
                $0 start
            fi
        fi
        ;;
    restart)
        ## stop the service and regardless of whether it was
        ## running or not, start it again.
        $0 stop
        $ECHO "Sleeping for 5 seconds for graceful httpd shutdown ..."
        $SLEEP 5
        $0 start
        ;;
    *)
        $ECHO "Usage: $0 {start|stop|status|condrestart|restart}"
        exit 1
        ;;
esac
