#!/usr/bin/perl
#---------------------------------------------------------------------
# PSMT Version Check CGIモジュール
#---------------------------------------------------------------------
# Script name: verchk.cgi
# Create date: 2013/02/01(V2.0)
# Auther:       T.Oyamada
#---------------------------------------------------------------------
# Change:
# 2013/12/19 gethostbyaddrでの別名ホスト対応
# 2016/12/05 エージェント側からの更新データがNULLの場合にはデータ更新
#            しないように修正
# 2018/03/05 VDFバージョンが更新されないバグ修正
# 2023/12/06 レスポンスで204を返す場合にLength: 0も返すように修正
#---------------------------------------------------------------------
# All Rights Reserved, Copyright (c) Promark 2003-2023
#---------------------------------------------------------------------
use CGI;
use Socket;
use Fcntl;
use AnyDBM_File;
use Time::Local;


# バージョン管理データを置くディレクトリを指定します。
# Webサーバが読み書きできる権限が必要です。
$data_dir = "/var/www/manager/data";
$dist = "/var/www/manager/update/dist/VERSION";
$data_file = "$data_dir/client_db";

$lock_file = "$data_dir/.db.lock";

$query = new CGI;
$proscan = $query->param('p');
$product = $query->param('t');
$engine = $query->param('e');
$vdf = $query->param('v');
$packlib = $query->param('l');
$formats = $query->param('f');
$expire = $query->param('d');
$signature = $query->param('s');
$update = $query->param('u');

$ip = $ENV{'REMOTE_ADDR'};
#@T = localtime;
#$update = sprintf("%04d/%02d/%02d %02d:%02d:%02d",$T[5]+1900,$T[4]+1,$T[3],$T[2],$T[1],$T[0]);

if ( -f $dist ) {
    open(VER,"$dist");
    $dist_version = <VER>;
    chomp($dist_version);
    close(VER);
}

open(LOCK,">$lock_file");
flock(LOCK,2);

open(LOG,">>/var/www/manager/logs/verchk.log");

if(tie( %client_data, 'AnyDBM_File', $data_file, O_CREAT|O_RDWR, 0644 )) {
print LOG "$data_file\n";
print LOG scalar(keys %client_data),"\n";
print LOG `id`;
print LOG `pwd`;

$addr = inet_aton($ip);
($host,$aliases) = gethostbyaddr($addr,AF_INET);
@alias = split(/ /,$aliases);

$data = $client_data{$host};
unless ($data) {
    foreach $h ( @alias ) {
        $host = $h;
        $data = $client_data{$host};
	last if $data;
    }
}

print LOG "$host:$ip:$data\n";
print LOG "$proscan:$engine:$vdf\n";
if ( $data ) {
    @D = split(/,/,$data);
    $group = $D[1];
    $type = $D[2];
    $status = &status_check($dist_version,$client_data{$host});
    $proscan = $D[4] unless $proscan;
    $engine = $$D[6] unless $engine;
    $vdf = $D[9] unless $vdf;
    $update = $D[11] unless $update;
    $expire = $D[12] unless $expire;
    $scan_result = $D[13];
    $scan_time = $D[14];
    $config = $D[15];
    $schedule = $D[16];

    if ( $update eq "" ) {
    	@T = localtime;
    	$date = sprintf("%04d/%02d/%02d",$T[5]+1900,$T[4]+1,$T[3]);
    	$time = sprintf("%02d:%02d:%02d",$T[2],$T[1],$T[0]);
    	$update = "$date $time";
    }

    $client_data{$host} = qq($ip,$group,$type,$status,$proscan,$product,$engine,$packlib,$formats,$vdf,$signature,$update,$expire,$scan_result,$scan_time,$config,$schedule);
}
untie(%client_data);
}
close(LOCK);
unlink($lock_file);

#$data_file = "$data_dir/update_result_db";
#tie( %result_data, 'AnyDBM_File', $data_file, O_CREAT|O_RDWR, 0600 );
#$result_data{$ip} = "u";
#untie(%result_data);

print <<EOF;
Status: 204

EOF
print LOG "$expire:$update\n";

close(LOG);

sub vchl {
    my($v1,$v2) = @_;
    $v1 = sprintf("%d%03d%03d%03d",split(/\./,$v1));
    $v2 = sprintf("%d%03d%03d%03d",split(/\./,$v2));
    return ($v1 - $v2);
}

sub status_check {
    my($latest,$current) = @_;
    my($proscan,$products,$engine,$plib,$format,$vdf,$signature) = split(/,/,$latest);
    my @D = split(/,/,$current);
    $cp1 = vchl($proscan,$D[4]);
    $cp2 = vchl($engine,$D[6]);
    $cp3 = vchl($vdf,$D[9]);
    
    return 0 if $cp1<=0 && $cp2<=0 && $cp3<=0;
    return 1 if $cp1>0 || $cp2>0 || $cp3>0;
    return 2 if $cp1>0 && $cp2>0 && $cp3>0;
}

