#!/bin/sh
#-------------------------------------------------
# ProScan Management Tool Manager Installer
#
# All Rights Reserved, Copyright (C) Promark Inc. 2006-2024
#
# ver 2.3.13 installer
#
# 2023.06.19 update 
# 2023.09.08 update ppc64leΉ
# 2024.12.01 psmt_passwdR}hɑΉ
#            OS,Apache check
#
MANAGER=$1
PASSWORD=$2
PORT=$3
CURRENT_DIR=`pwd`
INSTALL_DIR=/var/www/manager
UPDATE_DIR=$INSTALL_DIR/update
DOCUMENT_ROOT=/var/www/html
OS=`uname`

# OS version check
if [ "$OS" = "Linux" ]
then
    if [ ! -f /etc/os-release ]
    then
	echo "[error] Linux only support RedHat"
	exit
    fi
    support=0
    . /etc/os-release
    for os in $ID $ID_LIKE
    do
	if [ "$os" = "rhel" ]
	then
	    support=1
	    break
	fi
    done
    if [ $support -eq 0 ]
    then
	echo "[error] Linux only support RedHat"
	exit
    fi
    VER=`echo $VERSION_ID|awk '{print $0 * 100}'`
    if [ $VER -lt 800 ]
    then
	echo "[error] Only RedHat 8 and higher is supported"
	exit
    fi

elif [ "$OS" = "AIX" ]
then
    OSV=`oslevel|cut -d. -f1`
    OSSV=`oslevel|cut -d. -f2`
    if [ $OSV -lt 7 -o $OSSV -lt 2 ]
    then
	echo "[error] AIX $OSV.$OSSV not supported"
	exit
    fi
else
    echo "[error] $OS not supported"
    exit
fi

# httpd check
CHK=`httpd -v|grep "Server version: Apache/2.4"`
if [ "$CHK" = "" ]
then
    echo "[error] Only Apache 2.4 and higher is suppoted"
    exit
fi

# param check
if [ "$MANAGER" = "" ]
then
    echo "Usage: manager_install.sh MANAGER [PASSWORD] [PORT]"
    exit
fi

if [ "$PASSWORD" = "" ]
then
    PASSWORD=psmtadmin
fi

if [ "$PORT" = "" ]
then
    PORT=8505
fi

make_dir() {
    DIR_NAME=$1
    DIR=""
    for dir in `echo $DIR_NAME|awk '{n=split($0,path,"/")} END{for(i=1;i<=n;i++) printf("%s ",path[i])}'`
    do
        DIR="$DIR/$dir"
        if [ ! -d $DIR ]
        then
            mkdir $DIR
        fi
    done
}

copy_file() {
    SRC=$1
    DST=$2
    if [ -f $SRC ]
    then
	EXT=`echo $SRC|cut -d. -f2`
	if [ "$EXT" = "pl" -o "$EXT" = "sh" -o "$EXT" = "cgi" -o "$EXT" = "conf" ]
	then
            sed -e "s/192.168.100.155/$MANAGER/g;s/8505/$PORT/g;s#/var/www/manager#$INSTALL_DIR#g;s#/var/www/html/update#$UPDATE_DIR#g" $SRC > $DST
	    if [ "$EXT" != "conf" ]
	    then
		chmod a+x $DST
	    fi
	else
	    cp -p $SRC $DST
        fi
    fi
}

# User create
CHK=`grep psmtadm /etc/passwd`
if [ "$CHK" = "" ]
then
    if [ "$OS" = "AIX" ]
    then
	mkgroup psmtadm
	useradd -d $INSTALL_DIR -g psmtadm psmtadm
	chuser login=false psmtadm
    else
	groupadd psmtadm
	useradd -d $INSTALL_DIR -g psmtadm -s /bin/false psmtadm
    fi
fi

# Directory create
make_dir $INSTALL_DIR
cd $INSTALL_DIR
for d in bin cgi data html logs mirror tmp
do
    if [ ! -d $d ]
    then
        mkdir $d
    fi
done
cd data
for d in config download license scanlog
do
    if [ ! -d $d ]
    then
        mkdir $d
    fi
done
make_dir $UPDATE_DIR

# Copy module
cd $CURRENT_DIR/bin
for f in *
do
    copy_file $f $INSTALL_DIR/bin/$f
done
cd $INSTALL_DIR/bin
if [ "$OS" = "AIX" ]
then
    ARCH=aix
else
    ARCH=`arch`
fi
if [ "$ARCH" = "s390" -o "$ARCH" = "s390x" ]
then
    mv manager_s390 manager
fi
if [ "$ARCH" = "ppc64le" ]
then
    cp manager_ppc64le manager
fi
if [ "$ARCH" = "x86_64" ]
then
    cp manager_x86_64 manager
    cp psmt_passwd_x86_64 psmt_passwd
fi
if [ "$ARCH" = "aix" ]
then
    cp manager_aix manager
    cp psmt_passwd_aix psmt_passwd
fi
rm manager_* psmt_passwd_*
chmod a+x manager psmt_passwd

cd $CURRENT_DIR/cgi
for f in *
do
    copy_file $f $INSTALL_DIR/cgi/$f
done
cd $CURRENT_DIR/html
cp * $INSTALL_DIR/html
cd $CURRENT_DIR/mirror
for f in *
do
    copy_file $f $INSTALL_DIR/mirror/$f
done
if [ "$OS" = "AIX" ]
then
    copy_file $CURRENT_DIR/bin/psmt_httpd_aix.sh /etc/rc.d/init.d/psmt_httpd
else
    if [ -d /etc/init.d ]
    then
	copy_file $CURRENT_DIR/bin/psmt_httpd.sh /etc/init.d/psmt_httpd
    fi
    if [ -d /lib/systemd ]
    then
	cp -p $CURRENT_DIR/conf/psmt_httpd.service /lib/systemd/system
    fi
fi

chmod a+x $INSTALL_DIR/mirror/sigtool

# admin user create
$INSTALL_DIR/bin/mkuser.pl $PASSWORD

# set manager password
HTPASSWD=$INSTALL_DIR/bin/psmt_passwd
if [ "$HTPASSWD" != "" -a -x $HTPASSWD ]
then
    $HTPASSWD -B -c $INSTALL_DIR/data/passwd admin $PASSWORD
    $HTPASSWD -B -c $INSTALL_DIR/data/passwd download $PASSWORD
else
    echo "Could not creat PSMT web account"
    echo "Please create an account later using the command below."
    echo "    psmt_passwd -B -c $INSTALL_DIR/data/passwd admin PASSWORD"
    echo "    psmt_passwd -B -c $INSTALL_DIR/data/passwd download PASSWORD"
fi

# Owner change
chown -R psmtadm:psmtadm $INSTALL_DIR
chown -R psmtadm:psmtadm $DOCUMENT_ROOT

# httpd.conf
if [ -d /etc/httpd/conf ]
then
    if [ -f /etc/httpd/conf/psmt_httpd.conf ]
    then
	mv /etc/httpd/conf/psmt_httpd.conf /etc/httpd/conf/psmt_httpd.conf.back
    fi
    copy_file $CURRENT_DIR/conf/psmt_httpd.conf /etc/httpd/conf/psmt_httpd.conf
elif [ -d /opt/freeware/etc/httpd/conf ]
then
    if [ -f /opt/freeware/etc/httpd/conf/psmt_httpd.conf ]
    then
	mv /opt/freeware/etc/httpd/conf/psmt_httpd.conf /opt/freeware/etc/httpd/conf/psmt_httpd.conf.back
    fi
    if [ "$OS" = "AIX" ]
    then
	copy_file $CURRENT_DIR/conf/psmt_httpd_aix.conf /opt/freeware/etc/httpd/conf/psmt_httpd.conf
    else
	copy_file $CURRENT_DIR/conf/psmt_httpd.conf /opt/freeware/etc/httpd/conf/psmt_httpd.conf
    fi
else
    echo "[error] Please set up Apache first."
    exit 1
fi

HTTPD=`ps axw|grep psmt_httpd|grep -v grep`
if [ "$HTTPD" = "" ]
then
    if [ "$OS" = "AIX" ]
    then
	/etc/rc.d/init.d/psmt_httpd start > /dev/null 2>&1
    else
	if [ -f /lib/systemd/system/psmt_httpd.service ]
	then
	    systemctl start psmt_httpd.service
	    systemctl enable psmt_httpd.service
	    systemctl status psmt_httpd.service
	else
	    echo "[notice] psmt_httpd not set startup script"
	fi
    fi
fi


