#!/bin/sh
IUM_DIR=/var/www/manager/mirror
UPDATE_DIR=/var/www/manager/update/latest
WGET=/usr/bin/wget
TEMP_DIR=/tmp/.proscan_mirror
IUM_PARAMETER=""
CLASS=ibm/power/PSHB07.lst
OS=`uname`
if [ "$OS" = "AIX" ]
then
	MD5SUM="csum -h MD5"
else
	MD5SUM="md5sum"
fi

for PARAM in "$@"
do
	case ${PARAM} in
		--update-servers=*)
			update_servers=`echo $PARAM | cut -d '=' -f2 | sed -e 's/,/ /g'`
			;;

		--nodns)
			dns_resolv=no
			;;

		--proxy-host=*)
			PROXY_HOST=`echo $PARAM | cut -d '=' -f2`
			if [ "$PROXY_HOST" = "" ]
			then
				echo "proxy host failed"
				exit 1
			fi
			;;

		--proxy-port=*)
			PROXY_PORT=`echo $PARAM | cut -d '=' -f2`
			if [ "$PROXY_PORT" = "" ]
			then
				echo "proxy port failed"
				exit 1
			fi
			;;

		--proxy-user=*)
			PROXY_USER=`echo $PARAM | cut -d '=' -f2`
			if [ "$PROXY_USER" = "" ]
			then
				echo "proxy user failed"
				exit 1
			fi
			;;

		--proxy-password=*)
			PROXY_PASS=`echo $PARAM | cut -d '=' -f2`
			if [ "$PROXY_PASS" = "" ]
			then
				echo "proxy password failed"
				exit 1
			fi
			;;

		*)
			;;
	esac
done

#default setting
if [ "$update_servers" = "" ]
then
    update_servers="clamav-latest.promark-inc.com clamav-latest-2.promark-inc.com"
fi

#proxy setting
if [ "$PROXY_HOST" != "" ]
then
    http_proxy="http://$PROXY_HOST"
    if [ "$PROXY_PORT" != "" ]
    then
	http_proxy="$http_proxy:$PROXY_PORT"
    fi
    if [ "$PROXY_USER" != "" ]
    then
	WGET="$WGET --proxy-user=$PROXY_USER --proxy-password=$PROXY_PASS"
    fi
    export http_proxy
fi

make_dir() {
    DIR_NAME=`echo $1| sed -e 's/\/[^\/]*$//'`
    DIR=$2
    for dir in `echo $DIR_NAME|sed -e 's/\// /g'`
    do
        DIR="$DIR/$dir"
        if [ ! -d $DIR ]
        then
            mkdir $DIR
        fi
    done
}

get_file() {
    make_dir $1 $TEMP_DIR
    $WGET -q -O $TEMP_DIR/$1 http://$UPDATE_HOST/$1
    if [ $? -ne 0 ]
    then
        echo "could not download $1, server failed."
        return 1
    else
        sum=`$MD5SUM $TEMP_DIR/$1`
        chk=`echo $sum|grep $2`
        if [ "$chk" = "" ]
        then
            echo "could not download $1, checksum miss match!"
            return 1
        else
            echo "download $1, file was updated."
        fi
    fi
    return 0
}

mv_file() {
    make_dir $1 $UPDATE_DIR
    cp -p $1 $UPDATE_DIR/$1
}

# main logic

# make temporary directory
if [ ! -d $TEMP_DIR ]
then
    mkdir $TEMP_DIR > /dev/null 2>&1
else
    rm $TEMP_DIR/* > /dev/null 2>&1
fi

# get update list
for server in $update_servers
do
    echo "get psps_update.lst from $server ... \c"
    $WGET -q -O $TEMP_DIR/psps_update.lst http://$server/psps_update.lst
    if [ $? -eq 0 ]
    then
	echo "successful"
	flag=0
        break
    fi
    echo " failed"
    flag=1
done
if [ $flag -ne 0 ]
then
    echo "ProScan mirror failed. Update list could not download."
    exit 1
fi
UPDATE_HOST=$server

# check update file
RC=0
flag=0
exec 3<&0  < $TEMP_DIR/psps_update.lst
while read chksum file
do
    if [ -f $UPDATE_DIR/$file ]
    then
        sum=`$MD5SUM $UPDATE_DIR/$file`
        chk=`echo $sum|grep $chksum`
    else
        chk=""
    fi
    if [ "$chk" = "" ]
    then
        get_file $file $chksum
	if [ $? -ne 0 ]
	then
	    RC=`expr $RC + 1`
	else
	    flag=1
	fi
    fi
done
exec 0<&3 3<&-

rm $TEMP_DIR/psps_update.lst > /dev/null 2>&1

LANG=C
export $LANG

if [ $RC -eq 0 ]
then
	# is update
	if [ $flag -eq 1 ]
	then
	    cd $TEMP_DIR
	    list=`ls -lR | awk '/^\./ { dir=$1 } /^-/ { print dir $9 }'|sed -e 's/:/\//'`
	    for file in $list
	    do
	        mv_file $file
	    done
	fi
	
	VER=`head -1 $UPDATE_DIR/$CLASS|cut -d ' ' -f2`
	echo "psps6=$VER" >> $UPDATE_DIR/version.txt
fi

rm -r $TEMP_DIR > /dev/null 2>&1

exit $RC
