#!/bin/sh
DOCROOT=/var/www/html
UPDATE_DIR=/var/www/manager/update
BACKUP_ARCHIVES=5
LOG_LEVEL="local3.info"

if [ ! -f "$UPDATE_DIR/latest/VERSION" ]
then
    echo "Latest VERSION file not found"
    logger -i -p $LOG_LEVEL -t latest2dist -- "Error. Latest VERSION file not found."
    exit 1
fi

latest=`awk -F, '{print $1,$2,$3}' $UPDATE_DIR/latest/VERSION`
if [ -f "$UPDATE_DIR/dist/VERSION" ]
then
    current=`awk -F, '{print $1,$2,$3}' $UPDATE_DIR/dist/VERSION`
fi

WGET=/usr/bin/wget

if [ "$latest" = "$current" ]
then
    echo "up to date"
    exit 0
fi

rotate() {
    echo "rotation $1 ==> $2"
    # mv to backup
    SRC_DIR=$UPDATE_DIR/$1
    DST_DIR=$UPDATE_DIR/$2

    if [ -d $DST_DIR ]
    then
        rm -rf $DST_DIR
    fi
    cp -pr $SRC_DIR $DST_DIR
    if [ $? -ne 0 ]
    then
	logger -i -p $LOG_LEVEL -t latest2dist -- "Error. copy command error."
    fi
}

echo "rotation ..."

if [ -d "$UPDATE_DIR/backup2" ]
then
    cd $UPDATE_DIR
    NUM=`cat backup_number.txt`
    if [ "$NUM" = "" ]
    then
	NUM=0
    fi
    DATE=`date +%Y%m%d%H%M%S`
    if [ $NUM -ge $BACKUP_ARCHIVES ]
    then
	min=$DATE
	for FILE in `ls backup_*.tar.gz`
	do
	    cdate=`echo $FILE | cut -d _ -f 5 | cut -d . -f 1`
	    if [ $cdate -lt $min ]
	    then
		min=$cdate
		rmfile=$FILE
	    fi
	done
	rm $rmfile
	echo "$rmfile delete"
	NUM=`expr $NUM - 1`
    fi
    cd backup2
    VER=`cat VERSION | awk -F, '{print $1 "_" $2 "_" $3}'`
    echo "backup_${VER}_$DATE.tar.gz create"
    tar zcf ../backup_${VER}_$DATE.tar.gz ./*
    NUM=`expr $NUM + 1`
    echo $NUM > ../backup_number.txt
fi
if [ -d "$UPDATE_DIR/backup1" ]
then
    rotate backup1 backup2
fi
if [ -d "$UPDATE_DIR/backup0" ]
then
    rotate backup0 backup1
fi
if [ -d "$UPDATE_DIR/dist" ]
then
    rotate dist backup0
fi
if [ -d "$UPDATE_DIR/latest" ]
then
    rotate latest dist
    cp -pr $UPDATE_DIR/dist/* $DOCROOT
fi

echo "Now Latest Version. $latest"

exit 0
