#!/usr/bin/perl
#---------------------------------------------------------------------
# ProScan Download CGIモジュール
#---------------------------------------------------------------------
# Script name: download.cgi
# Create date: 2006/05/01(V1.0)
# Auther:       T.Oyamada
#---------------------------------------------------------------------
# Change:
# 2024/12/04 htpasswdコマンドを使わない方法に変更
#---------------------------------------------------------------------
# All Rights Reserved, Copyright (c) Promark 2003-2024
#---------------------------------------------------------------------
use CGI;
use Socket;
use Fcntl;
use AnyDBM_File;
use Time::Local;

require "/var/www/manager/cgi/config.cgi";

if ( $PSMTConfig::manager_ipaddr eq "" ) {
    print "Status: 501\n\nConfig read error\n";
    exit(1);
}

# バージョン管理データを置くディレクトリを指定します。
# Webサーバが読み書きできる権限が必要です。
$data_dir = "$PSMTConfig::manager_dir/data";

# パラメータ設定
$passwd_cmd = "$PSMTConfig::htpasswd";
$ip = $ENV{'REMOTE_ADDR'};

$query = new CGI;
$passwd = $query->param('pass');
$mode = $query->param('mode');
$mode = "common" unless $mode;
$file = $query->param('file');

$file = "agent_pkg.tar.gz" unless $file;
$file = "$ip.$file" if $mode ne "common";

$download_file = "$data_dir/download/$file";
$passwd_file = "$data_dir/passwd";

if (check_pass($passwd)) {
    print "Status: 403\n\nPassword error\n";
    exit(0);
}


if ( ! -f $download_file ) {
    print "Status: 404\n\nFile not found\n";
    print "Filename=$download_file\n";
    exit(0);
}

@STAT = stat($download_file);

print <<EOF;
Accept-Ranges: bytes
Content-Length: $STAT[7]
Content-Type: application/octet-stream

EOF

open(PKG,"$download_file");
while(sysread(PKG,$buffer,8192)) {
    print $buffer;
}
close(PKG);


sub check_pass {
    my($pass) = @_;
    my $salt;
    open(PASSWD,"$passwd_file");
    while(<PASSWD>) {
        chomp;
        ($id,$pw) = split(/:/,$_);
        last if $id eq "download";
    }
    close(PASSWD);
    if ( $pw =~ /^\$2y\$/ ) {
	($salt) = $pw =~ /^(\$2.\$\d\d\$.{22})/;
    } elsif ( $pw =~ /^\{sblowfish\}/ ) {
	($salt) = $pw =~ /^(\{sblowfish\}\d\d\$.{22})/;
    } else {
	($salt) = $pw =~ /(..)/;
    }
    my $crypt_pass = `$passwd_cmd $pass '$salt'`;
    chomp($crypt_pass);
    return 0 if $pw eq $crypt_pass;
    return 1;
}
