#! /usr/bin/perl
#---------------------------------------------------------------------
# ProScan Upload CGIモジュール
#---------------------------------------------------------------------
# Script name: upload.cgi
# Create date: 2024/11/20(V1.0)
# Auther:       T.Oyamada
#---------------------------------------------------------------------
# Change:
#---------------------------------------------------------------------
# All Rights Reserved, Copyright (c) Promark 2003-2024
#---------------------------------------------------------------------
use     strict;
use     utf8;
use     warnings;
use     CGI;
use     File::Copy;
use     HTTP::Date;

require "/var/www/manager/cgi/config.cgi";

print <<EOF;
Content-type: text/html

<!DOCTYPE html>
<html lang="ja">
<head>
<meta http-equiv="Content-Type" content="text/html; charset=utf-8" />
<title>Update Data Upload</title>
<script>
function FileUploadStart(F,M) {
    if ( M == 1 && F.files.value == "" ) {
        document.getElementById('msg').innerHTML = '';
        window.alert("アップロードファイルを指定してください");
        return false;
    }
    document.getElementById('msg').innerHTML = '<img src="/loadinfo.gif">';
    F.submit();
}
</script>
</head>
<body>
EOF

# --------------------------------------------------------------------
my $SAVE_DIR = "$PSMTConfig::manager_dir/tmp";
my $UPDATE_FILE;

my $q = CGI->new;
my $mode = $q->param('mode');
$mode = "form" unless $mode;

my $update_apply_command = "$PSMTConfig::manager_dir/bin/update_apply.sh";
my $date_string = HTTP::Date::time2iso;

if ( $PSMTConfig::manager_ipaddr eq "" ) {
    print "config.cgiが読み込めません<br>";
    $mode = "error";
}

if ( $mode eq "form" ) {

    print <<EOF;
<h2>データファイルをアップロードします</h2>
<p>psmt2.3_update_data.tar.gzをアップロードしてください。その他の形式のデータは利用できません。</p>
<form method="post" action="upload.cgi" enctype="multipart/form-data">
<input type="hidden" name="mode" value="upload">
<input type="file" name="files"  multiple>
<p><input type="button" value="送信" onClick="FileUploadStart(this.form,1)"></p>
</form>
<div id="msg" align="center" style="size: 120%;"></div>
EOF

} elsif ( $mode eq "upload" ) {

    my @files = $q->param ('files');

    for my $filename (@files)
    {
        if (copy($q->tmpFileName($filename), "$SAVE_DIR/$filename")) {
            $UPDATE_FILE = "$SAVE_DIR/$filename";
            print <<EOF;
<h2>データファイルのアップロードを完了しました</h2>
<p>「$filename」ファイルをアップロードしました</p>
<form method="post" action="upload.cgi" enctype="multipart/form-data">
<input type="hidden" name="mode" value="apply">
<input type="hidden" name="update_file" value="$UPDATE_FILE">
<p align="center"><input type="button" value="反映処理" onClick="FileUploadStart(this.form,2)">
<input type="button" value="閉じる" onClick="window.close()"></p>
<div id="msg" align="center" style="size: 120%;"></div>
</form>
EOF

        } else {
            print <<EOF;
<body>
<h2>データファイルのアップロードに失敗しました</h2>
<p>「$filename」ファイルをアップロードできませんでした</p>
<form method="post" action="upload.cgi" enctype="multipart/form-data">
<p align="center"><input type="button" value="閉じる" onClick="window.close()"></p>
</form>
EOF
        }
    }

} elsif ( $mode eq "apply" ) {

    $UPDATE_FILE = $q->param('update_file');
    if ( -f $UPDATE_FILE ) {

	# アップロードしたファイルの反映
	my $rc = `$update_apply_command "$UPDATE_FILE"`;
	chomp($rc);

	if ( $rc eq "ok" ) {

            print <<EOF;
<h2>データファイルの反映処理を完了しました</h2>
<p>アップデートデータが正しく反映されました</p>
<form method="post" action="upload.cgi" enctype="multipart/form-data">
<p align="center"><input type="button" value="閉じる" onClick="window.opener.location.reload();window.close()"></p>
</form>
EOF

	} else {

            print <<EOF;
<h2>データファイルの反映処理に失敗しました</h2>
<p>アップデートデータの反映処理でエラーが発生しました（$rc)</p>
<form method="post" action="upload.cgi" enctype="multipart/form-data">
<p align="center"><input type="button" value="閉じる" onClick="window.close()"></p>
</form>
EOF
	}
    } else {

	print <<EOF;
<h2>データファイルの反映処理に失敗しました</h2>
<p>アップデートデータファイルが存在しません</p>
<form method="post" action="upload.cgi" enctype="multipart/form-data">
<p align="center"><input type="button" value="閉じる" onClick="window.close()"></p>
</form>
EOF
    }
}

print <<EOF;
<hr />
<p>$date_string</p>
</body>
</html>
EOF

#
exit;

# --------------------------------------------------------------------
