#!/bin/sh
#-------------------------------------------------
# ProScan Management Tool Manager Updater
#
# All Rights Reserved, Copyright (C) Promark Inc. 2022-2025
#
#---- change log
# 2022.02.04 PSMT manager upgrade script
# 2024.12.26 Build 13 upgrade scrip
# 2025.01.27 psmt_passwd̃Rs[
#
MANAGER=$1
PORT=$2
CURRENT_DIR=`pwd`
INSTALL_DIR=/var/www/manager

# param check
if [ "$MANAGER" = "" ]
then
    echo "Usage: $0 MANAGER [PORT]"
    exit
fi

if [ "$PORT" = "" ]
then
    PORT=8505
fi

OS=`uname`

# OS version check
if [ "$OS" = "Linux" ]
then
    if [ ! -f /etc/os-release ]
    then
	echo "[error] Linux only support RedHat"
	exit
    fi
    support=0
    . /etc/os-release
    for os in $ID $ID_LIKE
    do
	if [ "$os" = "rhel" ]
	then
	    support=1
	    break
	fi
    done
    if [ $support -eq 0 ]
    then
	echo "[error] Linux only support RedHat"
	exit
    fi
    VER=`echo $VERSION_ID|awk '{print $0 * 100}'`
    if [ $VER -lt 800 ]
    then
	echo "[error] Only RedHat 8 and higher is supported"
	exit
    fi

elif [ "$OS" = "AIX" ]
then
    OSV=`oslevel|cut -d. -f1`
    OSSV=`oslevel|cut -d. -f2`
    if [ $OSV -lt 7 -o $OSSV -lt 2 ]
    then
	echo "[error] AIX $OSV.$OSSV not supported"
	exit
    fi
else
    echo "[error] $OS not supported"
    exit
fi

# httpd check
CHK=`httpd -v|grep "Server version: Apache/2.4"`
if [ "$CHK" = "" ]
then
    echo "[error] Only Apache 2.4 and higher is suppoted"
    exit
fi

copy_file() {
    SRC=$1
    DST=$2
    MOD=$3

    FTYPE=`grep 192.168.100.155 $SRC`
    if [ "$FTYPE" != "" ]
    then
	sed -e "s/192.168.100.155/$MANAGER/g;s/8505/$PORT/g;s#/var/www/manager#$INSTALL_DIR#g" $SRC > $DST
    fi

    # Mode & Owner change
    if [ "$MOD" = "exec" ]
    then
	chmod a+x $DST
    fi
    chown psmtadm:psmtadm $DST
}

# Copy module
if [ -d $CURRENT_DIR/new/bin ]
then
    cd $CURRENT_DIR/new/bin
    if [ "$OS" = "AIX" ]
    then
	ARCH=aix
    else
	ARCH=`arch`
    fi
    if [ "$ARCH" = "s390" -o "$ARCH" = "s390x" ]
    then
	mv manager_s390 manager
    fi
    if [ "$ARCH" = "ppc64le" ]
    then
	cp manager_ppc64le manager
    fi
    if [ "$ARCH" = "x86_64" ]
    then
	cp manager_x86_64 manager
	cp psmt_passwd_x86_64 psmt_passwd
    fi
    if [ "$ARCH" = "aix" ]
    then
	cp manager_aix manager
	cp psmt_passwd_aix psmt_passwd
    fi
    chmod a+x manager psmt_passwd

    for f in *
    do
        if [ -f $INSTALL_DIR/bin/$f ]
        then
	    cp -p $INSTALL_DIR/bin/$f $INSTALL_DIR/bin/$f.back
        fi
        copy_file $f $INSTALL_DIR/bin/$f exec
    done
fi

if [ -d $CURRENT_DIR/new/cgi ]
then
    cd $CURRENT_DIR/new/cgi
    for f in *
    do
        if [ -f $INSTALL_DIR/cgi/$f ]
        then
    	    cp -p $INSTALL_DIR/cgi/$f $INSTALL_DIR/cgi/$f.back
        fi
        copy_file $f $INSTALL_DIR/cgi/$f exec
    done
fi
if [ -d $CURRENT_DIR/new/html ]
then
    cd $CURRENT_DIR/new/html
    for f in *
    do
        if [ -f $INSTALL_DIR/html/$f ]
        then
	    cp -p $INSTALL_DIR/html/$f $INSTALL_DIR/html/$f.back
        fi
        copy_file $f $INSTALL_DIR/html/$f
    done
fi

if [ ! -d $INSTALL_DIR/tmp ]
then
    mkdir $INSTALL_DIR/tmp
    chown psmtadm:psmtadm $INSTALL_DIR/tmp
fi

